syntax = "proto2";

import "atest/proto/common.proto";

option java_package = "com.android.asuite.clearcut";

// Proto used by Atest CLI Tool for internal Users
message AtestLogEventInternal {

  // ------------------------
  // EVENT DEFINITIONS
  // ------------------------
  // Occurs immediately upon execution of atest
  message AtestStartEvent {
    optional string command_line = 1;
    repeated string test_references = 2;
    optional string cwd = 3;
    optional string os = 4;
    optional string source_root = 5;
    optional string hostname = 6;
  }

  // Occurs when atest exits for any reason
  message AtestExitEvent {
    optional Duration duration = 1;
    optional int32 exit_code = 2;
    optional string stacktrace = 3;
    optional string logs = 4;
  }

  // Occurs after a SINGLE test reference has been resolved to a test or
  // not found
  message FindTestFinishEvent {
    optional Duration duration = 1;
    optional bool success = 2;
    optional string test_reference = 3;
    repeated string test_finders = 4;
    optional string test_info = 5;
  }

  // Occurs after the build finishes, either successfully or not.
  message BuildFinishEvent {
    optional Duration duration = 1;
    optional bool success = 2;
    repeated string targets = 3;
  }

  // Occurs when a single test runner has completed
  message RunnerFinishEvent {
    optional Duration duration = 1;
    optional bool success = 2;
    optional string runner_name = 3;
    message Test {
      optional string name = 1;
      optional int32 result = 2;
      optional string stacktrace = 3;
    }
    repeated Test test = 4;
  }

  // Occurs after all test runners and tests have finished
  message RunTestsFinishEvent {
    optional Duration duration = 1;
  }

  // Occurs after detection of catching bug by atest have finished
  message LocalDetectEvent {
    optional int32 detect_type = 1;
    optional int32 result = 2;
  }

  // ------------------------
  // FIELDS FOR ATESTLOGEVENT
  // ------------------------
  optional string user_key = 1;
  optional string run_id = 2;
  optional UserType user_type = 3;
  optional string tool_name = 10;
  optional string sub_tool_name = 12;
  optional string user_name = 13 [deprecated = true];
  oneof event {
    AtestStartEvent atest_start_event = 4;
    AtestExitEvent atest_exit_event = 5;
    FindTestFinishEvent find_test_finish_event= 6;
    BuildFinishEvent build_finish_event = 7;
    RunnerFinishEvent runner_finish_event = 8;
    RunTestsFinishEvent run_tests_finish_event = 9;
    LocalDetectEvent local_detect_event = 11;
  }
}
